using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.IO;
using System.Windows.Forms;
using System.Xml;

namespace ConfigNS
{
    public partial class ConfigForm : Form
    {
        /// <summary>
        /// Reference to Config-object.
        /// </summary>
        private Config cfg;

        /// <summary>
        /// Shows the main form and references Config-object.
        /// </summary>
        /// <param name="cfg">A Config-object.</param>
        public ConfigForm(Config cfg)
        {
            InitializeComponent();
            this.cfg = cfg;
        }

        /// <summary>
        /// Exits application.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        /// <summary>
        /// Saves configuration to file.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void buttonOK_Click(object sender, EventArgs e)
        {
            try
            {
                this.cfg.Save();
                buttonOK.Enabled = false;
                MessageBox.Show("Konfiguration gespeichert in Datei:\n" + this.cfg.FileName);
            }
            catch (IOException ex1)
            {
                MessageBox.Show(ex1.Message);
            }
            catch (XmlException ex2)
            {
                MessageBox.Show(ex2.Message);
            }
        }

        /// <summary>
        /// Reads the Config-object and fills the treeview with its data.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ConfigForm_Load(object sender, EventArgs e)
        {
            treeViewConfig.Nodes.Clear();
            foreach (Section sec in this.cfg.sections.Values)
            {
                // create new root-node for each section
                TreeNode tn = new TreeNode(sec.name);
                tn.Name = sec.name;
                treeViewConfig.Nodes.Add(tn);
                
                foreach (Setting set in sec.settings.Values)
                {
                    // create new node for each setting
                    TreeNode tn2 = new TreeNode(set.name);
                    tn2.Name = set.name;
                    tn.Nodes.Add(tn2);
                }
            }
        }

        /// <summary>
        /// Enables changing of value if level 2 node is selected.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void treeViewConfig_AfterSelect(object sender, TreeViewEventArgs e)
        {
            if (e.Node.Level == 0)
            {
                // disable key/value-fields
                labelKey.Enabled = false;
                textBoxValue.Enabled = false;

                // expand/collapse level 1 nodes
                if (e.Node.IsExpanded)
                {
                    e.Node.Collapse();
                }
                else
                {
                    e.Node.Expand();
                }
            }
            else
            {
                // enable key/value-fields
                labelKey.Enabled = true;
                textBoxValue.Enabled = true;
                labelKey.Text = e.Node.Name;
                textBoxValue.Text = this.cfg.sections[e.Node.Parent.Name].settings[e.Node.Name].value;
            }
        }

        /// <summary>
        /// Saves the new value of a setting to the object.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void textBoxValue_TextChanged(object sender, EventArgs e)
        {
            string currentNode = treeViewConfig.SelectedNode.Name.ToString();
            string parentNode = treeViewConfig.SelectedNode.Parent.Name.ToString();
            if (textBoxValue.Text != this.cfg.sections[parentNode].settings[currentNode].value)
            {
                buttonOK.Enabled = true;
                this.cfg.sections[parentNode].settings[currentNode].value = textBoxValue.Text;
            }
        }
    }
}