using System;
using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Xml;

namespace ConfigNS
{
    public class Sections : DictionaryBase
    {
        /// <summary>
        /// Indexer.
        /// </summary>
        /// <param name="name">Name of the section.</param>
        /// <returns>The complete section.</returns>
        public Section this[string name]
        {
            set { this.Dictionary[name] = value; }
            get { return (Section)this.Dictionary[name]; }
        }

        /// <summary>
        /// Adds a section to the list.
        /// </summary>
        /// <param name="sectionName">Name of the section.</param>
        public void Add(string sectionName)
        {
            this.Dictionary.Add(sectionName, new Section(sectionName));
        }

        /// <summary>
        /// Removes a section from the list.
        /// </summary>
        /// <param name="sectionName">Name of the section.</param>
        public void Remove(string sectionName)
        {
            this.Dictionary.Remove(sectionName);
        }

        /// <summary>
        /// Implementation of "Values" for "foreach".
        /// </summary>
        public ICollection Values
        {
            get { return this.Dictionary.Values; }
        }

        /// <summary>
        /// Implementation of "Keys" for "foreach".
        /// </summary>
        public ICollection Keys
        {
            get { return this.Dictionary.Keys; }
        }

        /// <summary>
        /// Checks whether a section with the given name is set.
        /// </summary>
        /// <param name="sectionName">Name of section to search for.</param>
        /// <returns>True if section is found, else false.</returns>
        public bool SectionExists(string sectionName)
        {
            return this.Dictionary.Contains(sectionName);
        }

    }
}
