using System;
using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Xml;


namespace ConfigNS
{
    /// <summary>
    /// Class for all settings.
    /// </summary>
    public class Settings : DictionaryBase
    {
        /// <summary>
        /// Indexer.
        /// </summary>
        /// <param name="name">Name of the setting.</param>
        /// <returns>The complete setting.</returns>
        public Setting this[string name]
        {
            set { this.Dictionary[name] = value; }
            get { return (Setting)this.Dictionary[name]; }
        }

        /// <summary>
        /// Adds a setting to the list.
        /// </summary>
        /// <param name="settingName">Name of the setting.</param>
        /// <param name="defaultValue">Default value for the setting.</param>
        public void Add(string settingName, string defaultValue)
        {
            this.Dictionary.Add(settingName, new Setting(settingName, defaultValue));
        }

        /// <summary>
        /// Removes a setting from the list.
        /// </summary>
        /// <param name="settingName">Name of the setting.</param>
        public void Remove(string settingName)
        {
            this.Dictionary.Remove(settingName);
        }

        /// <summary>
        /// Implementation of "Values" for "foreach".
        /// </summary>
        public ICollection Values
        {
            get { return this.Dictionary.Values; }
        }

        /// <summary>
        /// Implementation of "Keys" for "foreach".
        /// </summary>
        public ICollection Keys
        {
            get { return this.Dictionary.Keys; }
        }

        /// <summary>
        /// Checks whether a setting with the given name is set.
        /// </summary>
        /// <param name="settingName">Name of the setting to search for.</param>
        /// <returns>True if setting is set, else false.</returns>
        public bool SettingExists(string settingName)
        {
            return this.Dictionary.Contains(settingName);
        }

    }
}
